==> zio-aws-kafka_2.13-6.20.56.2-sources.jar: zio/aws/kafka/model/RejectClientVpcConnectionRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RejectClientVpcConnectionRequest(
    clusterArn: Optional[__string] = Optional.Absent,
    vpcConnectionArn: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest = {
    import RejectClientVpcConnectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest
      .builder()
      .optionallyWith(clusterArn.map(value => value: java.lang.String))(
        _.clusterArn
      )
      .vpcConnectionArn(vpcConnectionArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.kafka.model.RejectClientVpcConnectionRequest.ReadOnly =
    zio.aws.kafka.model.RejectClientVpcConnectionRequest.wrap(buildAwsValue())
}
object RejectClientVpcConnectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.RejectClientVpcConnectionRequest =
      zio.aws.kafka.model.RejectClientVpcConnectionRequest(
        clusterArn.map(value => value),
        vpcConnectionArn
      )
    def clusterArn: Optional[__string]
    def vpcConnectionArn: __string
    def getClusterArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clusterArn", clusterArn)
    def getVpcConnectionArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(vpcConnectionArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest
  ) extends zio.aws.kafka.model.RejectClientVpcConnectionRequest.ReadOnly {
    override val clusterArn: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.clusterArn())
      .map(value => value: __string)
    override val vpcConnectionArn: __string = impl.vpcConnectionArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest
  ): zio.aws.kafka.model.RejectClientVpcConnectionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kafka_2.13-6.20.83.1-sources.jar: zio/aws/kafka/model/RejectClientVpcConnectionRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RejectClientVpcConnectionRequest(
    clusterArn: __string,
    vpcConnectionArn: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest = {
    import RejectClientVpcConnectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest
      .builder()
      .clusterArn(clusterArn: java.lang.String)
      .vpcConnectionArn(vpcConnectionArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.kafka.model.RejectClientVpcConnectionRequest.ReadOnly =
    zio.aws.kafka.model.RejectClientVpcConnectionRequest.wrap(buildAwsValue())
}
object RejectClientVpcConnectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.RejectClientVpcConnectionRequest =
      zio.aws.kafka.model
        .RejectClientVpcConnectionRequest(clusterArn, vpcConnectionArn)
    def clusterArn: __string
    def vpcConnectionArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
    def getVpcConnectionArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(vpcConnectionArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest
  ) extends zio.aws.kafka.model.RejectClientVpcConnectionRequest.ReadOnly {
    override val clusterArn: __string = impl.clusterArn(): __string
    override val vpcConnectionArn: __string = impl.vpcConnectionArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.RejectClientVpcConnectionRequest
  ): zio.aws.kafka.model.RejectClientVpcConnectionRequest.ReadOnly =
    new Wrapper(impl)
}
